@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,13 +39,13 @@ from rat import Rat
 from track import Track
 from _exceptions import MpdException
 
-def music_to_tracklist(music, velocity):
+def music_to_tracklist(music, velocity, start=None, end=None):
     """
     return a list of tracks, where track[0] use only channel 0,
     track[1] only use channel 1 etc.
     """
     score = parser.parse_to_score_object(music)
-    tracks = score.get_midi_events(velocity)
+    tracks = score.get_midi_events(velocity, start, end)
     return tracks
 
 def music_to_track(music, velocity, start=None, end=None):
@@ -56,7 +56,7 @@ def music_to_track(music, velocity, start=None, end=None):
         track.merge_with(tracklist[x])
     return track
 
-def play_music(music, tempo, patch, velocity):
+def play_music(music, tempo, patch, velocity, start=None, end=None):
     if type(tempo) == type(0):
         bpm = tempo
         nl = 4
@@ -68,6 +68,25 @@ def play_music(music, tempo, patch, velocity):
     [track.prepend_patch(patch) for track in tracklist]
     soundcard.synth.play_track(*tracklist)
 
+def play_music3(music, tempo, instrument, start=None, end=None):
+    """
+    Either a tuple (patch, velocity) or a tuple of 6:
+    (patch1, velocity1, p2, v2, p3, v3)
+    """
+    if len(instrument) == 2:
+        instrument = instrument * 3
+    # FIXME, only the velocity from instrument[1] is used since
+    # music_to_tracklist is not complete.
+    tracklist = music_to_tracklist(music, instrument[1], start, end)
+    tracklist[0].prepend_patch(instrument[4])
+    a, b = tempo
+    # FIXME the bpm api is wrong. We set the tempo to one track, and it works for all.
+    tracklist[0].prepend_bpm(a, b)
+    for track in tracklist[:-1][1:]:
+        track.prepend_patch(instrument[2])
+    tracklist[-1].prepend_patch(instrument[0])
+    soundcard.synth.play_track(*tracklist)
+
 ##################
 # midi functions #
 ##################
