@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,19 +15,22 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import const
-import gtk
-import mpdutils
 import operator
 
+import gtk
+import pango
+
+import const
+import mpdutils
+
 fetadir = "feta"
 class dim20:
     linespacing = 8
     stemlen = linespacing * 3.5
     xshift = 10
     col_width = 20
-    first_staff_ypos = 70
-    staff_spacing = 70
+    first_staff_ypos = 80
+    staff_spacing = 100
     ledger_left = -4
     ledger_right = 14
     accidental_widths = { -2: 12, -1: 7, 0: 5, 1: 8, 2: 8}
@@ -114,12 +117,13 @@ class TieEngraver(Engraver):
         self.m_shift2 = shift2
         self.m_ylinepos = ylinepos
     def set_xpos(self, dict):
+        dim = dimentions[self.m_fontsize]
         self.m_xpos = dict[self.m_pos1].m_music
         self.m_xpos2 = dict[self.m_pos2].m_music
-    def engrave(self, widget, gc, staff_yoffset):
-        dim = dimentions[self.m_fontsize]
         self.m_xpos += 3 + (self.m_shift1 + 1) * dim.xshift
         self.m_xpos2 += - 3 + self.m_shift2 * dim.xshift
+    def engrave(self, widget, gc, staff_yoffset):
+        dim = dimentions[self.m_fontsize]
         w = self.m_xpos2 - self.m_xpos
         h = 8
         widget.window.draw_arc(gc, False,
@@ -305,9 +309,12 @@ class TupletEngraver(Engraver):
         widget.window.draw_line(gc, x2, y, self.m_xpos2, y)
         widget.window.draw_line(gc, self.m_xpos1, y, self.m_xpos1, y+5*d)
         widget.window.draw_line(gc, self.m_xpos2, y, self.m_xpos2, y+5*d)
-        #FIXME shouldn't we use pango font string to be more portable?
-        font = gtk.load_font("-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*")
-        widget.window.draw_string(font, gc, m-3, y + 3, str(self.m_den))
+        cc = widget.create_pango_context()
+        ll = pango.Layout(cc)
+        ll.set_text(str(self.m_den))
+        ll.set_font_description(pango.FontDescription("Sans 10"))
+        sx, sy = [i / pango.SCALE for i in ll.get_size()]
+        widget.window.draw_layout(gc, m - sx / 2, y - sy / 2, ll)
 
 class BeamEngraver(Engraver):
     def __init__(self, fontsize):
