@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -112,31 +112,4 @@ class MThd:
         f.write("MThd")
         write_int32(f, len(v)) #chunk len
         write_vect(f, v)
-        
-        
-    
-if __name__ == "__main__":
-    import os
-    f = open("ut.midi", "w")
-    d = MThd(f)
-    v = []
-    #v = v + mf_timesig(4, 4)
-    # Not really necessary, since this tempo is the default
-    v = v + mf_tempo(120)
-    v = v + mf_program_change(0, 0)
-    v = v + mf_program_change(1, 0)
-    v = v + mf_program_change(2, 0)
-    v = v + mf_note_on(0, 0, 0x30, 0x60)
-    v = v + mf_note_on(100, 1, 0x31, 0x60)
-    v = v + mf_note_off(100, 0, 0x30, 0x40)
-    v = v + mf_note_off(0, 1, 0x31, 0x40)
-    v = v + mf_note_on(0, 0, 0x32, 0x60)
-    v = v + mf_note_off(100, 0, 0x32, 0x40)
-    v = v + mf_end_of_track()
-    f.write("MTrk")
-    write_int32(f, len(v))
-    write_vect(f, v)
-    f.close()
-    os.system("timidity ut.midi")  
-    os.system("rm ut.midi")
-    
+
