@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -70,7 +70,8 @@ class MusicDisplayer(gtk.ScrolledWindow):
         self._display()
     def _display(self):
         dim = engravers.dimentions[self.m_fontsize]
-        self.m_width = self.m_engravers[0][-1].m_xpos + 20
+        # BeamEngraver is the only engraver without m_xpos
+        self.m_width = max([e.m_xpos for e in self.m_engravers[0] if not isinstance(e, (engravers.BeamEngraver, engravers.TupletEngraver))]) + 20
         self.m_height = len(self.m_engravers)*dim.staff_spacing+dim.first_staff_ypos
         self.set_size_request(self.get_size_request()[0], self.m_height)
         self.g_d.set_size_request(self.m_width, self.m_height-4)
