@@ -84,7 +84,10 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
             self.m_timeout_handle = None
         self.q_status = self.QSTATUS_NO
         soundcard.synth.stop()
-        if self.m_statistics:
+        # We test for m_P because m_P might be None in some cases. For example
+        # if the user answers no when asked to run a lesson file that will 
+        # run external programs.
+        if self.m_statistics and self.m_P:
             self.m_statistics.save_data()
     def exit_test_mode(self):
         """
@@ -322,7 +325,7 @@ class RhythmAddOnClass:
         # FIXME can we use lessonfile.Rhythm insted of this?
         score = mpd.parser.parse_to_score_object(rhythm)
         track = score.get_midi_events_as_percussion(cfg.get_int('config/preferred_instrument_velocity'))[0]
-        track.prepend_bpm(self.m_P.header.bpm)
+        track.prepend_bpm(self.get_int("bpm"))
         track.replace_note(mpd.notename_to_int("c"),
                            self.get_int("config/rhythm_perc"))
         track.replace_note(mpd.notename_to_int("d"),
