@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -216,7 +216,7 @@ It is also possible that the OS sound setup is incorrect.
             module = self._practise_lesson_id(lesson_id)
         except (lessonfile.LessonfileParseException,
                 dataparser.DataparserException), e:
-            self.m_ui.display_exception_message(e)
+            self.m_ui.display_exception_message(e, lessonfile=self.lessonfile_manager.get(lesson_id, 'filename'))
             module = self.lessonfile_manager.get(lesson_id, 'module')
             self.m_teachers[module].m_P = None
         if 'm_discards' in dir(self.m_teachers[module].m_P):
@@ -257,7 +257,10 @@ It is also possible that the OS sound setup is incorrect.
         elif urlobj.protocol == 'solfege':
             self.handle_solfege_href(urlobj)
         elif urlobj.protocol == 'http':
-            webbrowser.open_new(href)
+            try:
+                webbrowser.open_new(href)
+            except Exception, e:
+                self.m_ui.display_error_message2(_("Error opening web browser"), str(e))
         elif urlobj.protocol == 'mailto':
             if self.get_string("config/mua"):
                 try:
