@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -225,6 +225,8 @@ class Gui(abstract.LessonbasedGui):
         """
         if event.button != 3:
             return
+        if not self.m_t.m_P.has_question():
+            return
         if not self.m_t.m_P.header.enable_right_click:
             self.g_flashbar.flash(_("Right click is not allowed for this lesson file."))
             return
@@ -233,13 +235,18 @@ class Gui(abstract.LessonbasedGui):
             d[k] = self.m_t.m_P.get_question()[k].cval
         # replace one property with the one we right clicked
         d[button.get_data('property_name')] = button.get_data('property_value')
-        for question in self.m_t.m_P.m_questions:
+        for idx, question in enumerate(self.m_t.m_P.m_questions):
             match = True
             for k in d:
                 if d[k] != question[k].cval:
                     match = False
             if match:
-                self.m_t.m_P.play_question(question)
+                try:
+                    self.m_t.m_P.play_question(question)
+                except Exception, e:
+                    e.m_question_idx = idx
+                    if not self.standard_exception_handler(e):
+                        raise
                 return
     def all_guessed_correct(self):
         self.run_exception_handled(self.show_answer)
@@ -273,7 +280,10 @@ class Gui(abstract.LessonbasedGui):
                 self.g_repeat.set_sensitive(True)
                 if self.get_bool('config/picky_on_new_question'):
                     self.g_new.set_sensitive(False)
-                self.g_repeat_arpeggio.set_sensitive(True)
+                if isinstance(self.m_t.m_P.get_question().music, lessonfile.ChordCommon):
+                    self.g_repeat_arpeggio.set_sensitive(True)
+                else:
+                    self.g_repeat_arpeggio.set_sensitive(False)
                 [btn for btn in self.g_atable.get_children() if isinstance(btn, gtk.Button)][-1].grab_focus()
         except Exception, e:
             if not self.standard_exception_handler(e, exception_cleanup):
