@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ class Teacher(abstract.Teacher):
     #UGH should we do this here
     def __init__(self, exname, app):
         abstract.Teacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.ChordLessonfile
+        self.lessonfileclass = lessonfile.QuestionsLessonfile
     def new_question(self):
         """
         return 1 if the teacher has a question to ask
@@ -176,10 +176,15 @@ class Gui(abstract.LessonbasedGui):
                 self.g_chordtype_box.get_children()[0].grab_focus()
             elif g == Teacher.ERR_PICKY:
                 self.g_flashbar.flash(_("You have to solve this question first."))
-        except lessonfile.LessonfileException, e:
-            if not self.standard_exception_handler(e, exception_cleanup):
-                raise
-        except mpd.MpdException, e:
+        except Exception, e:
+            # This is one place where m_mpd_badcode might be set, since it will
+            # be set if the exception is raisd by m_P.play_question(), but not
+            # by select_random_question called by m_t.new_question()
+            if isinstance(e, mpd.MpdException):
+                if 'm_mpd_varname' not in dir(e):
+                    e.m_mpd_varname = 'music'
+                if 'm_mpd_badcode' not in dir(e):
+                    e.m_mpd_badcode = self.m_t.m_P.get_question()['music'].get_err_context(e, self)
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def update_gui_after_lessonfile_change(self, *v):
@@ -222,6 +227,8 @@ class Gui(abstract.LessonbasedGui):
         self.g_redo.set_sensitive(False)
         self.show_music()
     def on_chordtype_right_clicked(self, button, event, t):
+        if event.button != 3:
+            return
         if self.m_t.m_P and not self.m_t.m_P.header.enable_right_click:
             self.g_flashbar.flash(_("Right click is not allowed for this lesson file."))
             return
@@ -236,23 +243,18 @@ class Gui(abstract.LessonbasedGui):
         try:
             # We try first with the 'set' variable, as this is what is closest
             if 'set' in self.m_t.m_P.get_question():
-                for question in self.m_t.m_P.m_questions:
+                for idx, question in enumerate(self.m_t.m_P.m_questions):
                     if question.set == self.m_t.m_P.get_question().set \
                             and question.name.cval == t:
                         self.m_t.m_P.play_question(question)
                         return
             #
-            for question in self.m_t.m_P.m_questions:
-                if question.name.cval == self.m_t.m_P.get_cname():
+            for idx, question in enumerate(self.m_t.m_P.m_questions):
+                if question.name.cval == button.get_data('chordtype'):
                     self.m_t.m_P.play_question(question)
                     return
-        except lessonfile.LessonfileException, e:
-            # This exception will be raised if for example the music
-            # type for a question is invalid.
-            if not self.standard_exception_handler(e):
-                raise
-        except mpd.MpdException, e:
-            # Invalid key variable or music code goes here.
+        except Exception, e:
+            e.m_question_idx = idx
             if not self.standard_exception_handler(e):
                 raise
     def on_chordtype_clicked(self, btn, t):
@@ -308,12 +310,12 @@ class Gui(abstract.LessonbasedGui):
         for x in self.g_chordtype_box.get_children():
             x.destroy()
         if self.m_t.m_P:
-            for ctype in self.m_t.m_P.m_props['name']:
-                b = gtk.Button(ctype)
-                b.set_data('chordtype', ctype.cval)
+            for name in [q.name for q in self.m_t.m_P.iterate_questions_with_unique_names()]:
+                b = gtk.Button(name)
+                b.set_data('chordtype', name.cval)
                 self.g_chordtype_box.pack_start(b, False)
-                b.connect('clicked', self.on_chordtype_clicked, ctype.cval)
-                b.connect('button_release_event', self.on_chordtype_right_clicked, ctype)
+                b.connect('clicked', self.on_chordtype_clicked, name.cval)
+                b.connect('button_release_event', self.on_chordtype_right_clicked, name)
                 b.show()
     def set_chordtype_frame_status_solved(self, t):
         for c in self.g_chordtype_box.get_children():
