@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -281,7 +281,12 @@ class Gui(abstract.Gui):
         self.g_music_displayer.clear()
         q = self.m_t.new_question()
         if q == Teacher.OK:
-            self.m_t.play_question()
+            try:
+                self.m_t.play_question()
+            except Exception, e:
+                if not self.standard_exception_handler(e, self.m_t.end_practise):
+                    raise
+                return
             self.g_first_is_largest.set_sensitive(True)
             self.g_first_is_largest.grab_focus()
             self.g_equal_size.set_sensitive(True)
