@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def __init__(self, app):
         gtk.Dialog.__init__(self, _("GNU Solfege Preferences"),
              app.m_ui, 0,
-             (gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
+             (gtk.STOCK_HELP, gtk.RESPONSE_HELP, gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
         cfg.ConfigUtils.__init__(self, 'configwindow')
         self.connect('response', self.apply_and_close)
         # We do this so that the window is only hidden when the
@@ -73,7 +73,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         # midi #
         ########
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi stuff")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi")))
 
         vbox, category_vbox = gu.hig_category_vbox(_("Tempo"))
         page_vbox.pack_start(vbox, False)
@@ -151,21 +151,16 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         category_vbox.pack_start(self.g_sex_female, False)
         if self.get_string('user/sex') == 'female':
             self.g_sex_female.set_active(True)
-        #######
-        # gui #
-        #######
+        #####################
+        # external programs #
+        #####################
         page_vbox = gu.hig_dlg_vbox()
-        self.g_notebook.append_page(page_vbox, gtk.Label(_("Gui")))
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("External programs")))
 
-        box, category_vbox = gu.hig_category_vbox(_("External programs"))
+        box, category_vbox = gu.hig_category_vbox(_("Convertors"))
         page_vbox.pack_start(box, False)
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
 
-        self.g_mail_program = gtk.Entry()
-        self.g_mail_program.set_text(self.get_string("config/mua"))
-        self.g_mail_program.connect('changed', lambda w: self.set_string('config/mua', self.g_mail_program.get_text()))
-        box = gu.hig_label_widget(_("_Mail program:"), self.g_mail_program, sizegroup)
-        category_vbox.pack_start(box)
         # midi_to_wav
         liststore = gtk.ListStore(gobject.TYPE_STRING)
         liststore.append(("/usr/bin/timidity -Ow %(in)s -o %(out)s",))
@@ -200,17 +195,33 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             gu.hig_label_widget(_("WAV to OGG convertor:"),
             self.g_ogg_convertor, sizegroup))
 
+        self.add_gui_for_external_programs(page_vbox)
+
         box, category_vbox = gu.hig_category_vbox(_("Misc"))
         page_vbox.pack_start(box, False)
 
+        liststore = gtk.ListStore(gobject.TYPE_STRING)
+        for n in ("xterm -e mutt", "thunderbird"):
+            liststore.append((n,))
+        self.g_mail_program = gtk.ComboBoxEntry(liststore)
+        self.g_mail_program.child.set_text(self.get_string("config/mua"))
+        self.g_mail_program.child.connect('changed', lambda w: self.set_string('config/mua', self.g_mail_program.child.get_text()))
+        box = gu.hig_label_widget(_("_Mail program:"), self.g_mail_program, sizegroup)
+        category_vbox.pack_start(box)
+
+        #######
+        # Gui #
+        #######
+        page_vbox = gu.hig_dlg_vbox()
+        self.g_notebook.append_page(page_vbox, gtk.Label(_("Gui")))
+
+        box, category_vbox = gu.hig_category_vbox(_("Gui"))
+        page_vbox.pack_start(box, False)
+
         self.g_mainwin_user_resizeable = gu.nCheckButton('gui',
           'mainwin_user_resizeable', _("_User resizeable main window"))
         category_vbox.pack_start(self.g_mainwin_user_resizeable, False)
 
-        self.g_expert_mode = gu.nCheckButton('gui', 
-                'expert_mode', _("E_xpert mode"))
-        self.g_expert_mode.connect('toggled', self.m_app.reset_exercise)
-        category_vbox.pack_start(self.g_expert_mode, False)
         # Combobox to select language
         hbox = gtk.HBox()
         hbox.set_spacing(6)
@@ -247,12 +258,12 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         l = gtk.Label(_("You have to restart the program for the language change to take effect."))
         l.set_alignment(0.0, 0.5)
         category_vbox.pack_start(l)
+
         ############
         # Practise #
         ############
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Practise")))
-
         box, category_vbox = gu.hig_category_vbox(_("Practise"))
         page_vbox.pack_start(box, False)
 
@@ -262,6 +273,11 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         self.g_autorepeat_if_wrong = gu.nCheckButton('config', 'auto_repeat_question_if_wrong_answer', _("_Repeat question if the answer was wrong"))
         category_vbox.pack_start(self.g_autorepeat_if_wrong, False)
 
+        self.g_expert_mode = gu.nCheckButton('gui', 
+                'expert_mode', _("E_xpert mode"))
+        self.g_expert_mode.connect('toggled', self.m_app.reset_exercise)
+        category_vbox.pack_start(self.g_expert_mode, False)
+
 
         #########
         # sound #
@@ -272,14 +288,14 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.create_linux_sound_page()
         self.show_all()
     def add_gui_for_external_programs(self, page_vbox):
-        box, category_vbox = gu.hig_category_vbox(_("External programs"))
+        box, category_vbox = gu.hig_category_vbox(_("Audio players"))
         page_vbox.pack_start(box, False)
         if sys.platform != 'win32':
             format_info = [
                 {'id': 'wav',
                  # testfile is a file in lesson-files/share
                  'testfile': 'fifth-small-220.00.wav',
-                 'label': _(".wav file player"),
+                 'label': _("WAV file player"),
                  # players is a tuple of tuples. The inner tuple has to elements:
                  # '/path/to/player', 'comandline'
                  'players': (('/usr/bin/play', '/usr/bin/play %s'),
@@ -293,7 +309,7 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
         format_info.extend([
             {'id': 'midi',
              'testfile': 'fanfare.midi',
-             'label': _(".midi file player"),
+             'label': _("MIDI file player"),
              'players': (('/usr/bin/timidity', '/usr/bin/timidity -idqq %s'),
                          ('/usr/bin/drvmidi', '/usr/bin/drvmidi'),
                          ('/usr/bin/playmidi', '/usr/bin/playmidi'),
@@ -341,10 +357,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def create_linux_sound_page(self):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Sound setup")))
-
-        ###
-        self.add_gui_for_external_programs(page_vbox)
-
         #############
         # midi setup
         #############
@@ -402,8 +414,6 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def create_win32_sound_page(self):
         page_vbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(page_vbox, gtk.Label(_("Midi setup")))
-
-        self.add_gui_for_external_programs(page_vbox)
         #############
         # midi setup
         #############
@@ -454,6 +464,9 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def apply_and_close(self, w, response):
         if response ==  gtk.RESPONSE_DELETE_EVENT:
             self.set_gui_from_config()
+        elif response == gtk.RESPONSE_HELP:
+            self.m_app.handle_href("preferences-window.html")
+            return
         else:
             if self.on_apply() == -1:
                 self.set_gui_from_config()
@@ -464,17 +477,20 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             self.set_gui_from_config()
             self.play_midi_test_sound()
     def play_midi_test_sound(self):
-        mpd.play_music(r"""
-        \staff\relative c{
-          c16 e g c e, g c e g, c e g c4
-        }
-        \staff{
-          c4 e g8 e c4
-        }
-        """, 130, 0, 100)
-    def on_help(self, *v):
-        #FIXME It is stupid to display this help in the main window.
-        self.m_app.handle_href("preferences-window.html")
+        try:
+            mpd.play_music(r"""
+            \staff\relative c{
+              c16 e g c e, g c e g, c e g c4
+            }
+            \staff{
+              c4 e g8 e c4
+            }
+            """, 130, 0, 100)
+        except Exception, e:
+            if isinstance(e, osutils.OsUtilsException):
+                self.m_app.m_ui.display_exception_message(e)
+            else:
+                raise
     def on_apply(self, *v):
         """Returns -1 if sound init fails."""
         card_info = ""
