@@ -1,6 +1,6 @@
 # -*- coding: iso-8859-1 -*-
 # GNU Solfege - free ear training software
-# Copyright (C) 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# Copyright (C) 2001, 2002, 2003, 2004, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -179,7 +179,7 @@ class DataparserSyntaxError(DataparserException):
 
 class AssignmentToReservedWordException(DataparserException):
     def __init__(self, parser, bad_pos, word):
-        DataparserException.__init__(self, _("Assignment to the reserved word \"%(word)s in the file \"%(filename)s\"") % {'filename': parser.m_filename, 'word': word})
+        DataparserException.__init__(self, _("Assignment to the reserved word \"%(word)s\"") % {'word': word})
         # This variable is only used by the module test code.
         self.m_token = parser._lexer.m_tokens[bad_pos]
         self.m_nonwrapped_text = parser._lexer.get_err_context(bad_pos)
@@ -218,7 +218,9 @@ class Lexer:
         else:
             self.m_parser = parser
         r = re.compile("#.*?coding\s*[:=]\s*([\w_.-]+)")
-        m = r.match(src)
+        # according to http://www.python.org/dev/peps/pep-0263/
+        # the encoding marker must be in the first two lines
+        m = r.match("\n".join(src.split("\n")[0:2]))
         if m:
             src = unicode(src, m.groups()[0], errors="replace")
         else:
@@ -561,7 +563,8 @@ class Dataparser:
         #FIXME right now named_block is reserved to element blocks, but
         # I hope to move other blocks here too. Or at least questions should
         # use self.blocklists, I think.
-        assert blocktype == 'element'
+        if blocktype != 'element':
+            raise DataparserSyntaxError(self, self._lexer.pos - 2, 'The only named block allowed are "element"')
         if blocktype not in self.blocklists:
             self.blocklists[blocktype] = []
         elem = dict()
