@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -130,12 +130,10 @@ class Gui(abstract.LessonbasedGui):
         # tmp func used as callback function
         def f(w, start, end, self=self):
             try:
-                track = mpd.music_to_track(self.m_t.m_P.get_music(),
-                       self.get_int('config/preferred_instrument_velocity'),
-                       start, end)
-                track.prepend_bpm(*self.m_t.m_P.get_tempo())
-                track.prepend_patch(self.get_int('config/preferred_instrument'))
-                soundcard.synth.play_track(track)
+                mpd.play_music3(self.m_t.m_P.get_music(),
+                    self.m_t.m_P.get_tempo(),
+                    self.m_t.m_P.prepare_instrument_list(self.m_t.m_P.get_question()),
+                    start, end)
             except Exception, e:
                 if not self.standard_exception_handler(e, soundcard.synth.stop):
                     raise
@@ -172,14 +170,24 @@ class Gui(abstract.LessonbasedGui):
         Callers must catch exceptions.
         """
         fontsize = self.get_int('config/feta_font_size=20')
-        if self.m_t.m_P.get_clue_music():
-            self.g_music_displayer.display(self.m_t.m_P.get_clue_music(), fontsize)
-        elif self.m_t.m_P.get_clue_end():
-            self.g_music_displayer.display_range(self.m_t.m_P.get_music(),
-                        fontsize, Rat(0, 1), self.m_t.m_P.get_clue_end())
-        else:
-            self.g_music_displayer.display(self.m_t.m_P.get_music(), 
-                        fontsize, mpd.FIRST)
+        try:
+            if self.m_t.m_P.get_clue_music():
+                self.g_music_displayer.display(self.m_t.m_P.get_clue_music().get_mpd_music_string(self.m_t.m_P), fontsize)
+            elif self.m_t.m_P.get_clue_end():
+                self.g_music_displayer.display_range(self.m_t.m_P.get_music(),
+                            fontsize, Rat(0, 1), self.m_t.m_P.get_clue_end())
+            else:
+                self.g_music_displayer.display(self.m_t.m_P.get_music(), 
+                            fontsize, mpd.FIRST)
+        except Exception, e:
+            if self.m_t.m_P.get_clue_music():
+                e.m_mpd_varname = 'clue_music'
+            else:
+                e.m_mpd_varname = 'music'
+            if isinstance(e, mpd.MpdException):
+                if 'm_mpd_badcode' not in dir(e):
+                    e.m_mpd_badcode = self.m_t.m_P.get_question()[e.m_mpd_varname].get_err_context(e, self.m_t.m_P)
+            raise
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = self.QSTATUS_NEW
         if not self.m_t.m_P.m_questions:
@@ -203,7 +211,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_play.set_sensitive(False)
                 self.g_show.set_sensitive(False)
                 self.g_music_displayer.clear()
-            if not self.standard_exception_handler(e, self.cleanup_function):
+            if not self.standard_exception_handler(e, cleanup_function):
                 raise
         else:
             self.g_play.set_sensitive(True)
