@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2007  Tom Cato Amundsen
+# Copyright (C) 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -100,15 +100,3 @@ class ExceptionDialog(gtk.Dialog):
         l.show()
         self.msg_vbox.pack_start(l)
 
-if __name__ == '__main__':
-    v = []
-    try:
-        print v[1]
-    except Exception, e:
-        d = ExceptionDialog(e)
-        d.add_text("Para2 " * 20)
-        d.add_nonwrapped_text("""(line 3) bla bla bla bla bla bla bla bla bla bla bla bla
-(line 4) bla bla bla bla bla bla kjkkjkjkjkj kjkjkkkj bla bla bla bla bla bla
-(line 5) bla bla bla bla bla bla bla bla bla bla bla bla""")
-        d.run()
-        d.destroy()
