@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -386,7 +386,9 @@ class HarmonicProgressionLabel(gtk.HBox):
         if m3:
             self.m_str = self.m_str[len(m3.group()):]
             return "one", m3.groups()[0], None
-        return "err"
+        c = self.m_str[0]
+        self.m_str = self.m_str[1:]
+        return "err", c, None
     def twoline(self, A, B):
         vbox = gtk.VBox()
         t1 = gtk.Label(A)
