@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -307,9 +307,18 @@ class Gui(abstract.IntervalGui):
             self.g_repeat.set_sensitive(True)
             self.g_repeat_melodic.set_sensitive(True)
             self.g_input.set_first_note(self.m_t.m_tonika)
+            def exception_cleanup():
+                self.m_t.end_practise()
+                self.g_repeat.set_sensitive(False)
+                self.g_repeat_melodic.set_sensitive(False)
+            try:
+                self.m_t.play_question()
+            except Exception, e:
+                if not self.standard_exception_handler(e, exception_cleanup):
+                    raise
+                return
             self.g_new_interval.set_sensitive(
               not self.get_bool('config/picky_on_new_question'))
-            self.m_t.play_question()
             self.g_flashbar.clear()
             #inputwidget 0 is always the buttons.
             if self.get_int('inputwidget') == 0:
