@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -113,6 +113,7 @@ class Gui(abstract.LessonbasedGui):
         try:
             g = self.m_t.new_question()
             if g == self.m_t.OK:
+                self.m_t.play_question()
                 self.g_music_displayer.display(self.m_t.m_P.get_music(),
                             self.get_int('config/feta_font_size=20'), mpd.FIRST)
                 self.g_repeat.set_sensitive(True)
@@ -123,12 +124,8 @@ class Gui(abstract.LessonbasedGui):
                 self.g_entry.set_text("")
                 self.g_new.set_sensitive(
                      not self.get_bool('config/picky_on_new_question'))
-                self.m_t.play_question()
                 self.g_entry.grab_focus()
-        except mpd.MpdException, e:
-            if not self.standard_exception_handler(e, exception_cleanup):
-                raise
-        except lessonfile.LessonfileException, e:
+        except Exception, e:
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def give_up(self, widget=None):
