@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,23 +52,4 @@ class History:
         self.m_lock = 1
     def unlock(self):
         self.m_lock = 0
-if __name__ == '__main__':
-    def test(s):
-        try:
-            exec("assert " + s)
-        except:
-            print "test failed: %s" % s
-    h = History()
-    for i in 'one', 'two', 'three', 'four':
-        h.add(i)
-    test("h.get_current() == 'four'")
-    h.back()
-    test("h.get_current() == 'three'")
-    h.back()
-    test("h.get_current() == 'two'")
-    h.add("five")
-    test("h.get_current() == 'five'")
-    h.back()
-    test("h.get_current() == 'two'")
-    h.forward()
-    test("h.get_current() == 'five'")
+
