@@ -793,7 +793,7 @@ def _test():
     w = TestWin()
     gtk.main()
 
-if runtime.has_gtkhtml2():
+if runtime.use_gtkhtml2():
     import gtkhtml2
     HtmlWidget = GtkHtml2Widget
 else:
