@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007 Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -188,14 +188,14 @@ class Gui(abstract.LessonbasedGui):
         self.g_display_music.set_sensitive(False)
         self.g_play_music.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
-        if [q for q in self.m_t.m_P.m_questions if q.music.is_transposable()]:
+        if [q for q in self.m_t.m_P.m_questions if isinstance(q.music, lessonfile.MpdTransposable)]:
             self.g_random_transpose_box.show()
         else:
             self.g_random_transpose_box.hide()
         # If one or more of the questions is of musictype 'chord', then
         # we need the "Repeat arpeggio" button.
         if [q for q in self.m_t.m_P.m_questions \
-            if isinstance(q.music, lessonfile.Chord)]:
+            if isinstance(q.music, lessonfile.ChordCommon)]:
             self.g_repeat_arpeggio.show()
         else:
             self.g_repeat_arpeggio.hide()
@@ -244,16 +244,17 @@ class Gui(abstract.LessonbasedGui):
             return
         try:
             if 'set' in self.m_t.m_P.get_question():
-                for question in self.m_t.m_P.m_questions:
+                for idx, question in enumerate(self.m_t.m_P.m_questions):
                     if question.set == self.m_t.m_P.get_question().set \
                         and question.name.cval == button.get_data('cname'):
                         self.m_t.m_P.play_question(question)
                         return
-            for question in self.m_t.m_P.m_questions:
+            for idx, question in enumerate(self.m_t.m_P.m_questions):
                 if question.name.cval == button.get_data('cname'):
                     self.m_t.m_P.play_question(question)
                     return
         except Exception, e:
+            e.m_question_idx = idx
             if not self.standard_exception_handler(e):
                 raise
     def on_left_click(self, button):
@@ -284,7 +285,7 @@ class Gui(abstract.LessonbasedGui):
                         self.m_t.m_P.play_question()
                     self.g_give_up.set_sensitive(True)
         except Exception, e:
-            if not self.standard_excpetion_handler(e):
+            if not self.standard_exception_handler(e):
                 raise
     def new_question(self, widget=None):
         """
@@ -320,10 +321,10 @@ class Gui(abstract.LessonbasedGui):
                 self.g_give_up.set_sensitive(False)
                 self.g_show.set_sensitive(False)
                 self.g_flashbar.clear()
-        except lessonfile.NoQuestionConfiguredException, e:
-            self.g_flashbar.clear()
-            self.g_flashbar.flash(_("You have to select some questions to practise."))
         except Exception, e:
+            if isinstance(e, mpd.MpdException):
+                if 'm_mpd_badcode' not in dir(e):
+                    e.m_mpd_badcode = self.m_t.m_P.get_question()['music'].get_err_context(e, self)
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
@@ -350,7 +351,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_music_displayer.clear()
         # We only want the Show button if there are any questions that can
         # be displayed.
-        if [q for q in self.m_t.m_P.m_questions if q['music'].is_displayable()] and not self.m_t.m_P.header.have_music_displayer:
+        if [q for q in self.m_t.m_P.m_questions if isinstance(q.music, lessonfile.MpdDisplayable)] and not self.m_t.m_P.header.have_music_displayer:
             self.g_show.show()
         else:
             self.g_show.hide()
