@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -148,7 +148,14 @@ class Gui(abstract.Gui):
         self.set_int('level', adjustment.value)
         self.update_buttons()
     def on_new(self, _o=None):
-        if self.m_t.new_question():
+        try:
+            n = self.m_t.new_question()
+        except Exception, e:
+            if not self.standard_exception_handler(e):
+                raise
+            self.m_t.stop_question()
+            return
+        if n:
             self.g_new.set_sensitive(
               not self.get_bool('config/picky_on_new_question'))
             self.g_give_up.set_sensitive(True)
