@@ -283,6 +283,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     self.set_float('%s_weight' % n, self.m_t.m_P.header.white_keys_weight[idx])
             else:
                 print "white_keys_weight had wrong type"
+        else:
+            for idx, n in enumerate(('c', 'd', 'e', 'f', 'g', 'a', 'b')):
+                self.set_float('%s_weight' % n, 0.0)
         if 'black_keys_weight' in self.m_t.m_P.header:
             if type(self.m_t.m_P.header.black_keys_weight) == list \
                     and len(self.m_t.m_P.header.black_keys_weight) == 5:
@@ -290,6 +293,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     self.set_float('%s_weight' % n, self.m_t.m_P.header.black_keys_weight[idx])
             else:
                 print "black_keys_weight had wrong type"
+        else:
+            for idx, n in enumerate(('cis', 'dis', 'fis', 'gis', 'ais')):
+                self.set_float('%s_weight' % n, 0.0)
         if self.m_t.m_custom_mode:
             self.g_config_elems.show()
         else:
