@@ -758,9 +758,9 @@ class Window(gtk.Window):
         renderer.set_property('editable', True)
         renderer.connect('edited', self.on_title_edited)
         model = self.g_treeview.get_model()
-        column = gtk.TreeViewColumn("Name", renderer, text=0)
+        column = gtk.TreeViewColumn(_("Name"), renderer, text=0)
         self.g_treeview.append_column(column)
-        column = gtk.TreeViewColumn("Type", renderer, text=1)
+        column = gtk.TreeViewColumn(_("Type"), renderer, text=1)
         self.g_treeview.append_column(column)
     def __create_model(self):
         self.m_model = gtk.TreeStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
