@@ -1198,7 +1198,7 @@ class IdPropertyLessonfile(QuestionsLessonfile):
         if not isinstance(self.header.qprop_labels, list):
             self.header.qprop_labels = [self.header.qprop_labels]
         if len(self.header.qprops) != len(self.header.qprop_labels):
-            raise LessonfileParseException(_("Error in the lesson file header of \"%(filename)s\". The variables qprops and qprop_labels has to have the same length.") % {'filename': self.m_filename})
+            raise LessonfileParseException(_("Error in the lesson file header of \"%(filename)s\". The variables qprops and qprop_labels must have the same length.") % {'filename': self.m_filename})
         # m_props will be a dict where each key is the property var name.
         # The values will be a list of possible values for that property.
         # The values are of type istr. This mean that .cval holds the
