@@ -73,9 +73,9 @@ opt_parser.add_option('--disable-exception-handler', action='store_true',
     help=_("Disable the exception handling in Gui.standard_exception_handler."))
 opt_parser.add_option('--no-random', action='store_true', dest='no_random',
     help=_('For debugging only: Select questions from lesson files in sequential order.'))
-opt_parser.add_option('--without-gtkhtml', action='store_true', 
-    dest='without_gtkhtml',
-    help=_('Run without using gtkhtml2 even if it is installed.'))
+opt_parser.add_option('--enable-gtkhtml', action='store_true', 
+    dest='enable_gtkhtml',
+    help=_('Run using gtkhtml2 instead of the built in HTML viewer.'))
 opt_parser.add_option('--no-cairo-widgets', action='store_true',
     dest='no_cairo_widgets',
     help=_("Do not use the cairo version of input widgets, even if we run gtk+ 2.8.0 or newer."))
