@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2005, 2007 Tom Cato Amundsen
+# Copyright (C) 2005, 2007, 2008 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,11 +43,3 @@ class PmWiki:
         return len(s) > 0
 
 
-def main():
-    w = PmWiki("http://localhost/~tom/pmwiki/pmwiki.php")
-    r = w.write_page('SITS-Incoming.TestPage', 'This is the test page. Time: %f' % time.time(), 'tomcato');
-    print "Does exist:", w.page_exists("Main.TestPage")
-    print "Does not exist:", not w.page_exists("Main.TestPageXX")
-
-if __name__ == '__main__':
-    main()
