@@ -124,7 +124,7 @@ class ReportBugWindow(gtk.Dialog):
             "Long desciption: %s\n" % description,
             "||border=1",
             "|| Solfege version||%s ||" % configureoutput.VERSION_STRING,
-            "|| runtime.has_gtkhtml2||%s ||" % runtime.has_gtkhtml2(),
+            "|| runtime.use_gtkhtml2||%s ||" % runtime.use_gtkhtml2(),
             "|| gtk.pygtk_version||%s ||" % str(gtk.pygtk_version),
             "|| gtk||%s ||" % gtk,
             "|| sys.version_info||%s||" % str(sys.version_info),
