@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -251,8 +251,9 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         if not self.g_rhythm_viewer.m_data:
             self.g_backspace.set_sensitive(False)
     def play_users_answer(self, widget):
-        rhythm = " ".join([abstract.RhythmAddOnClass.RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
-        self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
+        if self.g_rhythm_viewer.m_data:
+            rhythm = " ".join([abstract.RhythmAddOnClass.RHYTHMS[c] for c in self.g_rhythm_viewer.m_data])
+            self.m_t.play_rhythm(r"\staff{ %s }" % rhythm)
     def guess_element(self, sender, i):
         if self.m_t.q_status == self.QSTATUS_NO:
             self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
@@ -261,6 +262,7 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
             return
         if self.g_rhythm_viewer.len() == len(self.m_t.m_question):
             self.g_rhythm_viewer.clear_wrong_part()
+        self.g_backspace.set_sensitive(True)
         self.g_rhythm_viewer.add_rhythm_element(i)
         if self.g_rhythm_viewer.len() == len(self.m_t.m_question):
             if self.m_t.guess_answer(self.g_rhythm_viewer.m_data):
@@ -277,8 +279,6 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
                     if not v[x]:
                         self.g_rhythm_viewer.mark_wrong(x)
                 self.g_rhythm_viewer.sad_face()
-        else:
-            self.g_backspace.set_sensitive(True)
     def new_question(self, widget=None):
         g = self.m_t.new_question()
         if g == self.m_t.OK:
@@ -287,9 +287,14 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
             self.g_rhythm_viewer.create_holders()
             self.g_show.set_sensitive(True)
             self.g_repeat.set_sensitive(True)
+            try:
+                self.m_t.play_question()
+            except Exception, e:
+                if not self.standard_exception_handler(e, self.on_end_practise):
+                    raise
+                return
             self.g_new.set_sensitive(
                not self.get_bool('config/picky_on_new_question'))
-            self.m_t.play_question()
         elif g == self.m_t.ERR_PICKY:
             self.g_rhythm_viewer.flash(_("You have to solve this question first."))
         else:
