@@ -26,7 +26,7 @@ other initial setup tasks.
 import sys
 import os
 
-_has_gtkhtml2 = None
+_use_gtkhtml2 = False
 use_cairo_widgets = None
 
 def assert_python_version(required_version):
@@ -56,13 +56,12 @@ def setup_pygtk(required_version):
 
 
 def init(options):
-    global _has_gtkhtml2
+    global _use_gtkhtml2
     global use_cairo_widgets
     assert_python_version((2, 3))
     setup_pygtk((2, 4))
-    if options.without_gtkhtml:
-        _has_gtkhtml2 = False
-        print "gtkhtml2: disabled by runtime option"
+    if options.enable_gtkhtml:
+        _use_gtkhtml2 = True
     if options.no_cairo_widgets:
         use_cairo_widgets = False
     else:
@@ -74,17 +73,11 @@ def init(options):
 
 
 
-def has_gtkhtml2():
-    global _has_gtkhtml2
-    if _has_gtkhtml2 is not None:
-        return _has_gtkhtml2
-    print "Checking for gtkhtml2...",
-    try:
+def use_gtkhtml2():
+    global _use_gtkhtml2
+    if _use_gtkhtml2:
         import gtkhtml2
-        print "ok"
-        _has_gtkhtml2 = True
-    except ImportError, e:
-        print e
-        _has_gtkhtml2 = False
-    return _has_gtkhtml2
+        return True
+    else:
+        return False
 
