@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2004, 2005, 2007  Tom Cato Amundsen
+# Copyright (C) 2004, 2005, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,15 +31,10 @@ class Teacher(abstract.Teacher):
         abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingAnswerLessonfile
     def new_question(self):
-        # TODO This function is very similar to the one in src/idbyname.py
-        self.q_status = self.QSTATUS_NO
         assert self.m_P
-        try:
-            self.m_P.select_random_question()
-            self.q_status = self.QSTATUS_NEW
-            return self.OK
-        except lessonfile.NoQuestionConfiguredException:
-            return self.ERR_NO_QUESTION
+        self.m_P.select_random_question()
+        self.q_status = self.QSTATUS_NEW
+        return self.OK
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -73,17 +68,20 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.clear()
         try:
             g = self.m_t.new_question()
-            if self.m_t.m_P.get_question().music.is_displayable():
+            self.g_flashbar.push(self.m_t.m_P.get_question().question_text)
+            if isinstance(self.m_t.m_P.get_question().music, lessonfile.MpdDisplayable):
                 self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
             else:
                 self.g_music_displayer.clear()
-            self.g_flashbar.push(self.m_t.m_P.get_question().question_text)
             self.m_t.m_P.play_question()
             self.g_repeat.set_sensitive(True)
             self.g_repeat_arpeggio.set_sensitive(True)
             self.g_play_answer.set_sensitive(True)
             self.g_play_answer.grab_focus()
         except Exception, e:
+            if isinstance(e, mpd.MpdException):
+                e.m_mpd_varname = 'music'
+                e.m_mpd_badcode = self.m_t.m_P.get_question().music.get_err_context(e, self.m_t.m_P)
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def hear_answer(self, widget):
