@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ class Gui(abstract.LessonbasedGui):
         self.practise_box.pack_start(self.g_music_displayer)
 
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
-        gu.bButton(self.action_area, _("440h_z"), lambda f, s=self: s.m_t.play_440hz())
+        gu.bButton(self.action_area, _("440h_z"), self.play_440hz)
         self.g_play_answer = gu.bButton(self.action_area, _("_Play answer"),
             lambda w: self.run_exception_handled(self.m_t.m_P.play_question_arpeggio))
         self.practise_box.show_all()
@@ -56,7 +56,7 @@ class Gui(abstract.LessonbasedGui):
         def exception_cleanup():
             soundcard.synth.stop()
             self.g_play_answer.set_sensitive(False)
-            self.g_music_displayer.clear()
+            self.g_music_displayer.clear(2)
         try:
             self.m_t.new_question()
             fontsize = self.get_int('config/feta_font_size=20')
@@ -64,8 +64,9 @@ class Gui(abstract.LessonbasedGui):
             self.g_play_answer.set_sensitive(True)
             self.m_t.play_440hz()
         except Exception, e:
-            e.m_mpd_varname = 'music'
-            e.m_mpd_badcode = self.m_t.m_P.get_question().music.m_musicdata
+            if isinstance(e, mpd.MpdException):
+                e.m_mpd_varname = 'music'
+                e.m_mpd_badcode = self.m_t.m_P.get_question().music.get_err_context(e, self.m_t.m_P)
             if not self.standard_exception_handler(e, exception_cleanup):
                 raise
     def on_start_practise(self):
@@ -86,4 +87,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         self.g_new.set_sensitive(True)
         self.g_play_answer.set_sensitive(False)
+    def play_440hz(self, widget):
+        try:
+            self.m_t.play_440hz()
+        except Exception, e:
+            if not self.standard_exception_handler(e):
+                raise
 
