@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -193,7 +193,12 @@ class Gui(abstract.Gui):
             if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
                 self.do_test_complete()
                 return
-        r = self._new_question()
+        try:
+            r = self._new_question()
+        except Exception, e:
+            if not self.standard_exception_handler(e):
+                raise
+            return
         if r == Teacher.OK:
             self.g_new_interval.hide()
             self.g_new_interval_correct.show()
