@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 # old versions if incompatabilities are added.
 
 import sys
+import textwrap
 import time, os, pickle
 import utils
 import filesystem
@@ -124,9 +125,15 @@ class AbstractStatistics:
         for filename in os.listdir(datadir):
             t = int(filename)
             lt = time.localtime(t)
-            f = open(os.path.join(datadir, filename), 'r')
-            D = pickle.load(f)
-            f.close()
+            try:
+                f = open(os.path.join(datadir, filename), 'r')
+                D = pickle.load(f)
+                f.close()
+            except Exception, e:
+                print >> sys.stderr, "Error loading statistics from the file\n", os.path.join(datadir, filename)
+                print >> sys.stderr, "Exception:", (e,), e
+                print >> sys.stderr, "\n".join(textwrap.wrap("There is probably nothing to do except to delete the file. Don't bother reporting this as a bug, unless you can describe how to corrupt the file."))
+                continue
             now = int(time.time())
             lt_today = time.localtime(time.time())
             if lt[YEAR] == lt_today[YEAR] and \
