@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2007 Tom Cato Amundsen
+# Copyright (C) 2007, 2008 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -147,7 +147,7 @@ class TrainingSetDialog(gu.EditorDialogBase):
             fn = self.m_app.lessonfile_manager.get(lesson_id, 'filename')
             p = lessonfile.LessonfileCommon()
             p.parse_file(fn)
-            if not [q for q in p.m_questions if q.music.is_mpd_parsable()]:
+            if not [q for q in p.m_questions if isinstance(q.music, lessonfile.MpdParsable)]:
                 gu.dialog_ok(_("This lesson file cannot be exported because some of the music in the file are not parsable by the mpd module."))
                 return
         self.m_changed = True
