@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,9 +53,9 @@ class Teacher(abstract.Teacher):
         for n in self.m_question:
             s = s + " " + n
         s = s + "}"
-        track = mpd.music_to_track(s, self.get_int('config/preferred_instrument_velocity'))
-        track.prepend_patch(self.get_int('config/preferred_instrument'))
-        soundcard.synth.play_track(track)
+        mpd.play_music(s, 60,
+            self.get_int('config/preferred_instrument'),
+            self.get_int('config/preferred_instrument_velocity'))
 
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
@@ -78,7 +78,15 @@ class Gui(abstract.Gui):
         self.g_play_first_note.set_sensitive(True)
         self.g_play_last_note.set_sensitive(True)
         self.g_play_all.set_sensitive(True)
-        self.m_t.play_question()
+        try:
+            self.m_t.play_question()
+        except Exception,e:
+            def cleanup():
+                self.g_play_first_note.set_sensitive(False)
+                self.g_play_last_note.set_sensitive(False)
+                self.g_play_all.set_sensitive(False)
+            if not self.standard_exception_handler(e, cleanup):
+                raise
         s = r"\staff{"
         for n in self.m_t.m_question:
             s =  s + " " + n
