@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -244,3 +244,18 @@ class Url:
             if self.config:
                 self.config = _str_to_dict(self.config)
 
+
+def string_get_line_at(s, idx):
+    """
+    Return the whole line, excluding new-line characters, that
+    the character at idx is part of. It the char at idx is a new-line
+    character, then we consider this char the last character of the line.
+    """
+    start = idx
+    while start > 0 and s[start -1] != "\n":
+        start -= 1
+    end = idx
+    if s[end] != "\n":
+        while end < len(s) -1 and s[end + 1] != "\n":
+            end += 1
+    return s[start:end+1].strip("\n")
